==> config-api-5.1.0-sources.jar: com/sun/enterprise/config/serverbeans/customvalidators/ContextRootCheck.java <==
/*
 * Copyright (c) 2013, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.enterprise.config.serverbeans.customvalidators;

import java.lang.annotation.Target;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.ElementType;
import javax.validation.Constraint;
import javax.validation.Payload;

/**
 * ContextRootCheck constraint to verify a context root attribute is not a duplicate for a virtual server.
 *
 * @author Amy Roh
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
@Constraint(validatedBy = ContextRootCheckValidator.class)
public @interface ContextRootCheck {

    String message() default "Virtual server already has an application loaded at this context path therefore this application cannot be loaded at this context path on this virtual server";
    Class<?>[] groups() default {};
    Class<? extends Payload>[] payload() default {};

}

==> config-api-7.0.20-sources.jar: com/sun/enterprise/config/serverbeans/customvalidators/ContextRootCheck.java <==
/*
 * Copyright (c) 2013, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.enterprise.config.serverbeans.customvalidators;

import jakarta.validation.Constraint;
import jakarta.validation.Payload;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * ContextRootCheck constraint to verify a context root attribute is not a duplicate for a virtual server.
 *
 * @author Amy Roh
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
@Constraint(validatedBy = ContextRootCheckValidator.class)
public @interface ContextRootCheck {

    String message() default "Virtual server already has an application loaded at this context path therefore this application cannot be loaded at this context path on this virtual server";

    Class<?>[] groups() default {};

    Class<? extends Payload>[] payload() default {};

}
